@@ -2167,6 +2167,8 @@ class WidgetSquishTest(unittest.TestCase):
         assert c.rows() == 0
         c = w.render((80,0), focus=True)
         assert c.rows() == 0
+        c = w.render((80,1), focus=False)
+        assert c.rows() == 1
     
     def test_listbox(self):
         self.wstest(urwid.ListBox([]))
@@ -2177,6 +2179,7 @@ class WidgetSquishTest(unittest.TestCase):
     
     def test_graphvscale(self):
         self.wstest(urwid.GraphVScale([(0,"hello")], 1))
+        self.wstest(urwid.GraphVScale([(5,"hello")], 1))
     
     def test_solidfill(self):
         self.wstest(urwid.SolidFill())
@@ -2189,6 +2192,9 @@ class WidgetSquishTest(unittest.TestCase):
             urwid.BigText("hello",urwid.Thin6x6Font()),
             urwid.SolidFill(),
             'center', None, 'middle', None))
+        self.wstest(urwid.Overlay(
+            urwid.Text("hello"), urwid.SolidFill(),
+            'center',  ('relative', 100), 'middle', None))
 
     def test_frame(self):
         self.wstest(urwid.Frame(urwid.SolidFill()))
@@ -2200,10 +2206,10 @@ class WidgetSquishTest(unittest.TestCase):
 
     def test_pile(self):
         self.wstest(urwid.Pile([urwid.SolidFill()]))
+        self.wstest(urwid.Pile([]))
     
     def test_columns(self):
         self.wstest(urwid.Columns([urwid.SolidFill()]))
-    
 
 
 def test_main():
