@@ -82,7 +82,7 @@ class WidgetContainer(Widget):
         raise ValueError
 
     def count(self, value):
-        return sum(1 for v in self if v == value)
+        return sum([1 for v in self if v == value])
 
 
 
@@ -358,6 +358,7 @@ class Overlay(BoxWidget):
         """Return cursor coords from top_w, if any."""
         if not hasattr(self.body, 'get_cursor_coords'):
             return None
+        (maxcol, maxrow) = size
         left, right, top, bottom = self.calculate_padding_filler(size,
             True)
         x, y = self.top_w.get_cursor_coords(
@@ -395,7 +396,9 @@ class Overlay(BoxWidget):
             top, bottom =  calculate_filler( self.valign_type,
                 self.valign_amount, 'fixed', height, 
                 None, maxrow )
-        else:    
+            if height > maxrow: # flow widget rendered too large
+                bottom = maxrow - height
+        else:
             top, bottom = calculate_filler(self.valign_type, 
                 self.valign_amount, self.height_type, 
                 self.height_amount, self.min_height, maxrow)
@@ -420,14 +423,13 @@ class Overlay(BoxWidget):
         bottom_c = self.bottom_w.render(size)
         top_c = self.top_w.render(
             self.top_w_size(size, left, right, top, bottom), focus)
+        top_c = CompositeCanvas(top_c)
         if left<0 or right<0:
-            top_c = CompositeCanvas(top_c)
             top_c.pad_trim_left_right(min(0,left), min(0,right))
         if top<0 or bottom<0:
-            top_c = CompositeCanvas(top_c)
             top_c.pad_trim_top_bottom(min(0,top), min(0,bottom))
         
-        return CanvasOverlay(top_c, bottom_c, max(0,left), top)
+        return CanvasOverlay(top_c, bottom_c, left, top)
 
 
     def mouse_event(self, size, event, button, col, row, focus):
@@ -704,12 +706,15 @@ class Pile(Widget): # either FlowWidget or BoxWidget
         
         if focus_item is None:
             focus_item = 0
-        self.set_focus(focus_item)
+        if self.widget_list:
+            self.set_focus(focus_item)
+        else:
+            self.focus_item=None
         self.pref_col = 0
 
     def selectable(self):
         """Return True if the focus item is selectable."""
-        return self.focus_item.selectable()
+        return self.focus_item is not None and self.focus_item.selectable()
 
     def set_focus(self, item):
         """Set the item in focus.  
@@ -836,6 +841,8 @@ class Pile(Widget): # either FlowWidget or BoxWidget
             if canv:
                 combinelist.append((canv, i, item_focus))
             i+=1
+        if not combinelist:
+            return SolidCanvas(" ", size[0], (size[1:]+(0,))[0])
 
         return CanvasCombine(combinelist)
     
